@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
 from django.apps import AppConfig
 
 
 class LocalAppConfig(AppConfig):
     name = 'local_app'
+    default = False
